@@ -2,7 +2,7 @@ package WebService::PayPal::PaymentsAdvanced::Error::HTTP;
 
 use Moo;
 
-our $VERSION = '0.000012';
+our $VERSION = '0.000013';
 
 extends 'Throwable::Error';
 
@@ -22,7 +22,7 @@ WebService::PayPal::PaymentsAdvanced::Error::HTTP - An HTTP transport error
 
 =head1 VERSION
 
-version 0.000012
+version 0.000013
 
 =head1 SYNOPSIS
 
@@ -52,9 +52,7 @@ version 0.000012
 
 =head1 DESCRIPTION
 
-This class represents an error which is embedded into the HTML of a hosted
-form.   It will only be thrown if you have enabled
-L<WebService::PayPal::PaymentsAdvanced/validate_hosted_form_uri>.
+This class represents an HTTP transport error.
 
 It extends L<Throwable::Error> and adds one attribute of its own.
 
@@ -65,8 +63,8 @@ inherited from L<Throwable::Error>.
 
 =head2 http_response
 
-Returns the L<HTTP::Response> object which was returned when attempting to GET
-the hosted form.
+Returns the L<HTTP::Response> object which was returned when attempting the
+HTTP request.
 
 =head2 http_status
 
